summaryrefslogtreecommitdiff
path: root/mysql-test/mysql-test-run.pl
diff options
context:
space:
mode:
authorTor Didriksen <tor.didriksen@oracle.com>2011-08-18 16:35:46 +0200
committerTor Didriksen <tor.didriksen@oracle.com>2011-08-18 16:35:46 +0200
commitcde19f0a48817b4f5e396fc93355ca0918e58fa0 (patch)
treec4a6a94a20b32844bb9fa8aa12bcf2cd32ccb7b2 /mysql-test/mysql-test-run.pl
parentee789c28b4cf1ac42f975730b567016d3965ea81 (diff)
downloadmariadb-git-cde19f0a48817b4f5e396fc93355ca0918e58fa0.tar.gz
BUG#12818561 - RELEASE-LIKE PACKAGE CONTAINS AN EXTRA 'PLUGIN' FOLDER
Look for suite/thread_pool/plugin.defs
Diffstat (limited to 'mysql-test/mysql-test-run.pl')
-rwxr-xr-xmysql-test/mysql-test-run.pl5
1 files changed, 3 insertions, 2 deletions
diff --git a/mysql-test/mysql-test-run.pl b/mysql-test/mysql-test-run.pl
index ec0ca74b1d1..9dc4f2e515e 100755
--- a/mysql-test/mysql-test-run.pl
+++ b/mysql-test/mysql-test-run.pl
@@ -450,8 +450,9 @@ sub main {
#
read_plugin_defs("include/plugin.defs");
- # Also read from any plugin local plugin.defs
- for (glob "$basedir/plugin/*/tests/mtr/plugin.defs") {
+ # Also read from any plugin local or suite specific plugin.defs
+ for (glob "$basedir/plugin/*/tests/mtr/plugin.defs".
+ " suite/*/plugin.defs") {
read_plugin_defs($_);
}